# Generated by Django 2.2.13 on 2020-06-21 16:01

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Account',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(help_text='A friendly name to recognize this account.', max_length=32, verbose_name='name')),
                ('slug', models.SlugField(help_text="This slug is used for this account's notification URL.", unique=True, verbose_name='slug')),
                ('app_id', models.CharField(help_text='The APP_ID given by MercadoPago.', max_length=16, verbose_name='client id')),
                ('secret_key', models.CharField(help_text='The SECRET_KEY given by MercadoPago.', max_length=32, verbose_name='secret key')),
                ('sandbox', models.BooleanField(default=True, help_text='Indicates if this account uses the sandbox mode, indicated for testing rather than real transactions.', verbose_name='sandbox')),
            ],
        ),
        migrations.CreateModel(
            name='Notification',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('status', models.CharField(choices=[('unp', 'Pending'), ('pro', 'Processed'), ('ign', 'Ignored'), ('ok', 'Okay'), ('404', 'Error 404'), ('err', 'Error')], default='unp', max_length=3, verbose_name='status')),
                ('topic', models.CharField(choices=[('o', 'Merchant Order'), ('p', 'Payment')], max_length=1)),
                ('resource_id', models.CharField(max_length=46, verbose_name='resource_id')),
                ('last_update', models.DateTimeField(auto_now=True, verbose_name='last_update')),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='notifications', to='mp.Account', verbose_name='owner')),
            ],
        ),
        migrations.CreateModel(
            name='Preference',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('mp_id', models.CharField(help_text='The id MercadoPago has assigned for this Preference', max_length=46, null=True, verbose_name='mercadopago id')),
                ('payment_url', models.URLField(verbose_name='payment url')),
                ('sandbox_url', models.URLField(verbose_name='sandbox url')),
                ('reference', models.CharField(max_length=128, unique=True, verbose_name='reference')),
                ('paid', models.BooleanField(default=False, help_text='Indicates if the preference has been paid.', verbose_name='paid')),
                ('owner', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='preferences', to='mp.Account', verbose_name='owner')),
            ],
        ),
        migrations.CreateModel(
            name='Payment',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('mp_id', models.BigIntegerField(unique=True, verbose_name='mp id')),
                ('status', models.CharField(max_length=16, verbose_name='status')),
                ('status_detail', models.CharField(max_length=100, verbose_name='status detail')),
                ('created', models.DateTimeField(verbose_name='created')),
                ('approved', models.DateTimeField(null=True, verbose_name='approved')),
                ('notification', models.OneToOneField(blank=True, help_text='The notification that informed us of this payment.', null=True, on_delete=django.db.models.deletion.PROTECT, related_name='payment', to='mp.Notification', verbose_name='notification')),
                ('preference', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='payments', to='mp.Preference', verbose_name='preference')),
            ],
        ),
        migrations.AddField(
            model_name='notification',
            name='preference',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.PROTECT, related_name='notifications', to='mp.Preference', verbose_name='preference'),
        ),
        migrations.CreateModel(
            name='Item',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('title', models.CharField(max_length=256, verbose_name='title')),
                ('currency_id', models.CharField(default='BRL', max_length=3, verbose_name='currency id')),
                ('description', models.CharField(max_length=256, verbose_name='description')),
                ('quantity', models.PositiveSmallIntegerField(default=1)),
                ('unit_price', models.DecimalField(decimal_places=2, max_digits=9)),
                ('preference', models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='items', to='mp.Preference', verbose_name='preference')),
            ],
            options={
                'verbose_name': 'item',
                'verbose_name_plural': 'items',
            },
        ),
        migrations.AlterUniqueTogether(
            name='notification',
            unique_together={('topic', 'resource_id')},
        ),
        migrations.AlterModelOptions(
            name='preference',
            options={'ordering': ('-id',), 'verbose_name': 'Preference'},
        ),
        migrations.AlterField(
            model_name='preference',
            name='mp_id',
            field=models.CharField(help_text='Id atribuído pelo MP', max_length=46, null=True, verbose_name='Id MP'),
        ),
        migrations.AlterField(
            model_name='preference',
            name='owner',
            field=models.ForeignKey(on_delete=django.db.models.deletion.PROTECT, related_name='preferences',
                                    to='mp.Account', verbose_name='Proprietário'),
        ),
        migrations.AlterField(
            model_name='preference',
            name='paid',
            field=models.BooleanField(default=False, help_text='Indica se foi pago ou não', verbose_name='Pago'),
        ),
        migrations.AlterField(
            model_name='preference',
            name='payment_url',
            field=models.URLField(verbose_name='URL de Pagamento'),
        ),
        migrations.AlterField(
            model_name='preference',
            name='reference',
            field=models.CharField(max_length=128, unique=True, verbose_name='Referência'),
        ),
        migrations.AlterField(
            model_name='preference',
            name='sandbox_url',
            field=models.URLField(verbose_name='URL Sandbox'),
        ),
    ]
